#
# spec file for package gap-normalizinterface
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gap-normalizinterface
Version:        1.3.7
Release:        1.3
Summary:        GAP: wrapper for Normaliz
License:        GPL-2.0-or-later
Group:          Productivity/Scientific/Math
URL:            https://gap-packages.github.io/NormalizInterface/
#Git-Clone:     https://github.com/gap-packages/NormalizInterface
Source:         https://github.com/gap-packages/NormalizInterface/releases/download/v%version/NormalizInterface-%version.tar.bz2
BuildRequires:  fdupes
BuildRequires:  gap-devel >= 4.12.1
BuildRequires:  gap-rpm-devel
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  normaliz-devel >= 3.5.4
Requires:       gap-core >= 4.12.1

%description
The NormalizInterface package provides a GAP interface to Normaliz,
enabling direct access to the complete functionality of Normaliz,
such as computations in affine monoids, vector configurations,
lattice polytopes, and rational cones.

%prep
%autosetup -n NormalizInterface-%version
# Use C++14 for libnormalize with e-antic, see
# https://github.com/gap-packages/NormalizInterface/issues/110
sed -i -e '/AX_CXX_COMPILE_STDCXX/ s/11,/14,/' configure.ac
sed -i -e '/CXXFLAGS/ s/gnu++11/gnu++14/' Makefile.in

%build
autoreconf -fi
%configure --with-gaproot="%gapdir" --with-normaliz="%_prefix"
%make_build

%install
%gappkg_simple_install
pushd "%buildroot/$moddir"
rm -Rf autom4te.cache config.log config.status configure~ gen/src/*.{o,d}
popd
%fdupes %buildroot/%_prefix

%files -f %name.files

%changelog
* Wed Aug 28 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.3.7
  * Require GAP >= 4.12.1; Use
    LoadKernelExtension/IsKernelExtensionAvailable
* Sun May 21 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.3.6
  * Improve compatibility with an upcoming GAP update
* Tue Feb 21 2023 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 1.3.5
  * Rename `build-normaliz.sh` to `prerequisites.sh` to match an
    undocumented convention used across several packages.
  * Minor build system tweaks
- Update to version 1.3.4
  * Fix regression that broke building NormalizInterface on macOS
- Update to version 1.3.3
  * Update to Normaliz 3.9.3
  * Improve build system to honor CPPFLAGS environment variable
  * Explicitly set a so-called "run path" / "rpath" when linking
    against the bundled copy of Normaliz (improves compatibility
    with future versions of the GAP compiler `gac`, which will
    not be using GNU libtool anymore)
- Update to version 1.3.2
  * Fix building on Cygwin
- Update to version 1.3.1
  * Fix building on FreeBSD
- Update to version 1.3.0
  * Update to Normaliz 3.9.1
  * Improve the new build system
  * Various janitorial changes
- Update to version 1.2.0
  * Update to Normaliz 3.8.4
  * New build system
  * Various janitorial changes
- Update to version 1.1.0
  * Add support for rational inputs, e.g. polytopes with rational
    coordinates
  * Update build system for improve compatibility with GAP >= 4.9
  * Completely rewrote build-normaliz.sh (now downloads a tarball
    using curl or wget, instead of cloning a git repository)
  * Fix a potential crash when freeing proxy cone objects
  * Fix 'unknown cone property' that could occur when using newer
    versions of Normaliz, e.g. version 3.5.4
  * Display the Normaliz version as part of banner string
  * Loads of internal and janitorial changes
  * Require Normaliz 3.5.4 or newer (and add support for its
    new features)
  * Sebastian Gutsche is no longer package maintainer
* Mon Dec 25 2017 jengelh@inai.de
- Update to new upstream release 1.0.2
  * update to libnormaliz 3.4.0
  * added cone properties
  * added wrappers for new normaliz functionality
* Mon Jun 20 2016 jengelh@inai.de
- Update to new upstream release 0.9.8
  * Support for normaliz 3.1.1 (declarative only; no changes)
* Wed Jun  8 2016 jengelh@inai.de
- Update to new upstream release 0.9.7
  * fix a bug in the conversion between GAP and Normaliz integer
  values, which could lead to wrong results for integers with
  absolute value roughly between 2^32 and 2^60
  * fix crash when using StructuralCopy on a cone (issue #38)
  * fix printing of certain integers on 32bit systems (issue #36)
  * give better diagnostics when loading NormalizInterface fails due
  to its kernel extension missing
* Sat Mar 12 2016 jengelh@inai.de
- Initial package (version 0.9.5) for build.opensuse.org
